@@ -15,7 +15,7 @@ use Convert::Wiki::Node;
 use vars qw/$VERSION @ISA/;
 
 @ISA = qw/Convert::Wiki::Node/;
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 #############################################################################
 
@@ -34,8 +34,8 @@ sub as_wiki
 
   my $p = '=' x ($self->{level} + 1);		# level 1: ==
 
-  # "== Foo ==\n"
-  $p . ' ' . $self->{txt} . ' ' . $p . "\n";
+  # "== Foo ==\n\n"
+  $p . ' ' . $self->{txt} . ' ' . $p . "\n\n";
   }
 
 1;
@@ -63,6 +63,8 @@ None by default.
 
 =head1 SEE ALSO
 
+The base class L<Convert::Wiki::Node>.
+
 =head1 AUTHOR
 
 Tels L<http://bloodgate.com>
